@@ -3,7 +3,7 @@ ldapurl - handling of LDAP URLs as described in RFC 4516
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapurl.py,v 1.48 2011/07/21 17:53:22 stroeder Exp $
+\$Id: ldapurl.py,v 1.51 2011/07/22 08:58:16 stroeder Exp $
 
 Python compability note:
 This module only works with Python 2.0+ since
@@ -11,7 +11,7 @@ This module only works with Python 2.0+ since
 2. list comprehensions are used.
 """
 
-__version__ = '2.4.2'
+__version__ = '2.4.3'
 
 __all__ = [
   # constants
@@ -203,7 +203,7 @@ class LDAPUrl:
         integer search scope for ldap-module
     filterstr
         String representation of LDAP Search Filters
-        (see RFC 2254)
+        (see RFC 4515)
     extensions
         Dictionary used as extensions store
     who
@@ -357,7 +357,16 @@ class LDAPUrl:
     return ldap_url
   
   def htmlHREF(self,urlPrefix='',hrefText=None,hrefTarget=None):
-    """Complete """
+    """
+    Returns a string with HTML link for this LDAP URL.
+    
+    urlPrefix
+        Prefix before LDAP URL (e.g. for addressing another web-based client)
+    hrefText
+        link text/description
+    hrefTarget
+        string added as link target attribute
+    """
     assert type(urlPrefix)==StringType, "urlPrefix must be StringType"
     if hrefText is None:
       hrefText = self.unparse()
